@@ -30,9 +30,12 @@ my @compat = ( [ 0, 0.64 ],
 	       [ 0.65, 0.70,
 		 \&add_comment_fields,
 	       ],
-               [ 0.71, $Alzabo::VERSION,
+               [ 0.71, 0.73,
                  \&convert_pk_to_array,
                ],
+               [ 0.79, $Alzabo::VERSION,
+                 \&add_table_attributes,
+               ],
 	     );
 
 sub update_schema
@@ -119,7 +122,8 @@ EOF
     my $fh = do { local *FH; *FH };
     open $fh, "<$c_file"
 	or Alzabo::Exception::System->throw( error => "Unable to open $c_file: $!" );
-    my $raw = Storable::retrieve_fd($fh);
+    my $raw = Storable::fd_retrieve($fh)
+        or Alzabo::Exception::System->throw( error => "Can't read filehandle" );
     close $fh
 	or Alzabo::Exception::System->throw( error => "Unable to close $c_file: $!" );
 
@@ -132,7 +136,7 @@ EOF
     open $fh, ">$c_file"
 	or Alzabo::Exception::System->throw( error => "Unable to write to $c_file: $!" );
     Storable::nstore_fd( $raw, $fh )
-	    or Alzabo::Exception::System->throw( error => "Can't store to filehandle" );
+	or Alzabo::Exception::System->throw( error => "Can't store to filehandle" );
     close $fh
 	or Alzabo::Exception::System->throw( error => "Unable to close $c_file: $!" );
 
@@ -193,6 +197,17 @@ sub convert_pk_to_array
     }
 }
 
+sub add_table_attributes
+{
+    my $s = shift;
+
+    foreach my $table ( $s->tables )
+    {
+        tie %{ $table->{attributes} }, 'Tie::IxHash';
+    }
+}
+
+
 __END__
 
 =head1 NAME
