@@ -4,9 +4,11 @@ use strict;
 use vars qw($VERSION);
 
 use Alzabo::Create;
+use Alzabo::Exceptions ( abbr => 'params_exception' );
 
 use Params::Validate qw( :all );
-Params::Validate::validation_options( on_fail => sub { Alzabo::Exception::Params->throw( error => join '', @_ ) } );
+Params::Validate::validation_options
+    ( on_fail => sub { params_exception join '', @_ } );
 
 use base qw(Alzabo::Column);
 
@@ -30,27 +32,27 @@ sub _init
 {
     my $self = shift;
 
-    validate( @_, { table => { isa => 'Alzabo::Table' },
-		    name  => { type => SCALAR },
-		    null  => { optional => 1 },
-		    nullable => { optional => 1 },
-		    type  => { type => SCALAR,
-			       optional => 1 },
-		    attributes => { type => ARRAYREF,
-				    optional => 1 },
-		    default    => { type => UNDEF | SCALAR,
-				    optional => 1 },
-		    sequenced  => { optional => 1 },
-		    length => { type => UNDEF | SCALAR,
-				optional => 1 },
-		    precision  => { type => UNDEF | SCALAR,
-				    optional => 1 },
-		    definition => { isa => 'Alzabo::Create::ColumnDefinition',
-				    optional => 1 },
-		    comment => { type => UNDEF | SCALAR,
-				 default => '' },
+    my %p =
+        validate( @_, { table => { isa => 'Alzabo::Table' },
+                        name  => { type => SCALAR },
+                        null  => { optional => 1 },
+                        nullable => { optional => 1 },
+                        type  => { type => SCALAR,
+                                   optional => 1 },
+                        attributes => { type => ARRAYREF,
+                                        optional => 1 },
+                        default    => { type => UNDEF | SCALAR,
+                                        optional => 1 },
+                        sequenced  => { optional => 1 },
+                        length => { type => UNDEF | SCALAR,
+                                    optional => 1 },
+                        precision  => { type => UNDEF | SCALAR,
+                                        optional => 1 },
+                        definition => { isa => 'Alzabo::Create::ColumnDefinition',
+                                        optional => 1 },
+                        comment => { type => UNDEF | SCALAR,
+                                     default => '' },
 		  } );
-    my %p = @_;
 
     $self->set_table( $p{table} );
 
@@ -64,9 +66,12 @@ sub _init
     }
     else
     {
-	$self->set_definition( Alzabo::Create::ColumnDefinition->new( owner => $self,
-								      type => $p{type},
-								    ) );
+	$self->set_definition
+            ( Alzabo::Create::ColumnDefinition->new
+                  ( owner => $self,
+                    type => $p{type},
+                  )
+            );
     }
 
     my %attr;
@@ -98,9 +103,8 @@ sub set_name
     validate_pos( @_, { type => SCALAR } );
     my $name = shift;
 
-    Alzabo::Exception::Params->throw
-        ( error => "Column $name already exists in table" )
-            if $self->table->has_column($name);
+    params_exception "Column $name already exists in table"
+        if $self->table->has_column($name);
 
     my $old_name = $self->{name};
     $self->{name} = $name;
@@ -112,14 +116,8 @@ sub set_name
     if ($@)
     {
 	$self->{name} = $old_name;
-	if ( UNIVERSAL::can( $@, 'rethrow' ) )
-	{
-	    $@->rethrow;
-	}
-	else
-	{
-	    Alzabo::Exception->throw( error => $@ );
-	}
+
+        rethrow_exception($@);
     }
 
     $self->table->register_column_name_change( column => $self,
@@ -134,10 +132,10 @@ sub set_nullable
     validate_pos( @_, { type => SCALAR } );
     my $n = shift;
 
-    Alzabo::Exception::Params->throw( error => "Invalid value for nullable attribute: $n" )
+    params_exception "Invalid value for nullable attribute: $n"
 	unless $n eq '1' || $n eq '0';
 
-    Alzabo::Exception::Params->throw( error => "Primary key column cannot be nullable" )
+    params_exception "Primary key column cannot be nullable"
 	if $n eq '1' && $self->is_primary_key;
 
     $self->{nullable} = $n;
@@ -195,7 +193,7 @@ sub delete_attribute
     validate_pos( @_, { type => SCALAR } );
     my $attr = shift;
 
-    Alzabo::Exception::Params->throw( error => "Column " . $self->name . " doesn't have attribute $attr" )
+    params_exception "Column " . $self->name . " doesn't have attribute $attr"
 	unless exists $self->{attributes}{$attr};
 
     delete $self->{attributes}{$attr};
@@ -257,7 +255,7 @@ sub set_sequenced
     validate_pos( @_, { type => SCALAR } );
     my $s = shift;
 
-    Alzabo::Exception::Params->throw( error => "Invalid value for sequenced attribute: $s" )
+    params_exception "Invalid value for sequenced attribute: $s"
 	unless $s eq '1' || $s eq '0';
 
     $self->table->schema->rules->validate_sequenced_attribute($self)
@@ -316,7 +314,7 @@ C<Alzabo::Column>
 
 =head2 new
 
-=head3 Parameters
+The constructor accepts the following parameters:
 
 =over 4
 
@@ -354,23 +352,19 @@ An optional comment.
 
 =back
 
-=head3 Returns
+It returns a new C<Alzabo::Create::Column> object.
 
-A new C<Alzabo::Create::Column> object.
-
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =for pod_merge type
 
 =head2 alter
 
 This method allows you to change a column's type, length, and
-precision as a single operation and should be instead of calling
-C<set_type> followed by C<set_length>.
+precision as a single operation.  It should be instead of calling
+C<set_type()> followed by C<set_length()>.
 
-=head3 Parameters
+It takes the following parameters:
 
 =over 4
 
@@ -382,20 +376,31 @@ C<set_type> followed by C<set_length>.
 
 =back
 
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
+
 =head2 set_type ($type)
 
 Sets the column's type.
 
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
+
 =head2 set_table (C<Alzabo::Create::Table> object)
 
-Returns/sets the L<C<Alzabo::Create::Table>|Alzabo::Create::Table>
-object in which this column is located.
+Sets the L<C<Alzabo::Create::Table>|Alzabo::Create::Table> object in
+which this column is located.
+
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =for pod_merge name
 
 =head2 set_name ($name)
 
-Returns/sets the column's name (a string).
+Sets the column's name (a string).
+
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
 
 =for pod_merge nullable
 
@@ -404,9 +409,7 @@ Returns/sets the column's name (a string).
 Sets the nullability of the column (this determines whether nulls are
 allowed in the column or not).  Must be 0 or 1.
 
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =for pod_merge attributes
 
@@ -415,20 +418,23 @@ L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 =head2 set_attributes (@attributes)
 
 Sets the column's attributes.  These are strings describing the column
-(for example, valid attributes in MySQL are 'PRIMARY KEY' or
-'AUTO_INCREMENT').
+(for example, valid attributes in MySQL are "PRIMARY KEY" or
+"AUTO_INCREMENT").
+
+Throws: L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
 
 =head2 add_attribute ($attribute)
 
 Add an attribute to the column's list of attributes.
 
+Throws: L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
+
 =head2 delete_attribute ($attribute)
 
 Delete the given attribute from the column's list of attributes.
 
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
 
 =for pod_merge default
 
@@ -442,7 +448,7 @@ Sets the column's default value.
 
 =head2 set_length
 
-=head3 Parameters
+This method takes the following parameters:
 
 =over 4
 
@@ -452,9 +458,11 @@ Sets the column's default value.
 
 =back
 
-Sets the column's length and precision.  The precision parameter is
-optional (though some column types may require it if the length is
-set).
+This method sets the column's length and precision.  The precision
+parameter is optional (though some column types may require it if the
+length is set).
+
+Throws: L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
 
 =for pod_merge sequenced
 
@@ -462,9 +470,8 @@ set).
 
 Sets the value of the column's sequenced attribute.
 
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
 
 =for pod_merge is_primary_key
 
@@ -482,6 +489,11 @@ Sets the
 L<C<Alzabo::Create::ColumnDefinition>|Alzabo::Create::ColumnDefinition>
 object which holds this column's type information.
 
+=head2 former_name
+
+If the column's name has been changed since the last time the schema
+was instantiated, this method returns the column's previous name.
+
 =for pod_merge comment
 
 =head2 set_comment ($comment)
