@@ -4,9 +4,11 @@ use strict;
 use vars qw($VERSION);
 
 use Alzabo::Create;
+use Alzabo::Exceptions ( abbr => 'params_exception' );
 
 use Params::Validate qw( :all );
-Params::Validate::validation_options( on_fail => sub { Alzabo::Exception::Params->throw( error => join '', @_ ) } );
+Params::Validate::validation_options
+    ( on_fail => sub { params_exception join '', @_ } );
 
 use Tie::IxHash;
 
@@ -23,6 +25,8 @@ sub new
 
     validate( @_, { schema => { isa => 'Alzabo::Create::Schema' },
 		    name => { type => SCALAR },
+                    attributes => { type => ARRAYREF,
+                                    optional => 1 },
 		    comment => { type => UNDEF | SCALAR,
 				 default => '' },
 		  } );
@@ -38,6 +42,11 @@ sub new
     $self->{pk} = [];
     $self->{indexes} = Tie::IxHash->new;
 
+    my %attr;
+    tie %{ $self->{attributes} }, 'Tie::IxHash';
+
+    $self->set_attributes( @{ $p{attributes} } );
+
     $self->set_comment( $p{comment} );
 
     # Setting this prevents run time type errors.
@@ -53,9 +62,8 @@ sub set_name
     validate_pos( @_, { type => SCALAR } );
     my $name = shift;
 
-    Alzabo::Exception::Params->throw
-        ( error => "Table $name already exists in schema" )
-            if $self->schema->has_table($name);
+    params_exception "Table $name already exists in schema"
+        if $self->schema->has_table($name);
 
     my @i;
     if ($self->{indexes})
@@ -77,14 +85,8 @@ sub set_name
     if ($@)
     {
 	$self->{name} = $old_name;
-	if ( UNIVERSAL::can( $@, 'rethrow' ) )
-	{
-	    $@->rethrow;
-	}
-	else
-	{
-	    Alzabo::Exception->throw( error => $@ );
-	}
+
+        rethrow_exception($@);
     }
 
     if ( $old_name && eval { $self->schema->table($old_name) } )
@@ -133,7 +135,7 @@ sub add_column
 
     my $col = $p{column};
 
-    Alzabo::Exception::Params->throw( error => "Column " . $col->name . " already exists in " . $self->name )
+    params_exception "Column " . $col->name . " already exists in " . $self->name
 	if $self->{columns}->EXISTS( $col->name );
 
     $col->set_table($self) unless $col->table eq $self;
@@ -158,7 +160,7 @@ sub delete_column
     validate_pos( @_, { isa => 'Alzabo::Create::Column' } );
     my $col = shift;
 
-    Alzabo::Exception::Params->throw( error => "Column $col doesn't exist in $self->{name}" )
+    params_exception"Column $col doesn't exist in $self->{name}"
 	unless $self->{columns}->EXISTS( $col->name );
 
     $self->delete_primary_key($col) if $col->is_primary_key;
@@ -195,21 +197,22 @@ sub move_column
 
     if ( exists $p{before} && exists $p{after} )
     {
-	Alzabo::Exception::Params->throw( error => "move_column method cannot be called with both 'before' and 'after' parameters" );
+	params_exception
+            "move_column method cannot be called with both 'before' and 'after' parameters";
     }
 
     if ( exists $p{before} )
     {
-	Alzabo::Exception::Params->throw( error => "Column " . $p{before}->name . " doesn't exist in schema" )
+	params_exception "Column " . $p{before}->name . " doesn't exist in schema"
 	    unless $self->{columns}->EXISTS( $p{before}->name );
     }
     else
     {
-	Alzabo::Exception::Params->throw( error => "Column " . $p{after}->name . " doesn't exist in schema" )
+	params_exception "Column " . $p{after}->name . " doesn't exist in schema"
 	    unless $self->{columns}->EXISTS( $p{after}->name );
     }
 
-    Alzabo::Exception::Params->throw( error => "Column " . $p{column}->name . " doesn't exist in schema" )
+    params_exception "Column " . $p{column}->name . " doesn't exist in schema"
 	unless $self->{columns}->EXISTS( $p{column}->name );
 
     my @pk = $self->primary_key;
@@ -239,10 +242,10 @@ sub add_primary_key
     my $col = shift;
 
     my $name = $col->name;
-    Alzabo::Exception::Params->throw( error => "Column $name doesn't exist in $self->{name}" )
+    params_exception "Column $name doesn't exist in $self->{name}"
 	unless $self->{columns}->EXISTS($name);
 
-    Alzabo::Exception::Params->throw( error => "Column $name is already a primary key" )
+    params_exception "Column $name is already a primary key"
         if $col->is_primary_key;
 
     $self->schema->rules->validate_primary_key($col);
@@ -261,10 +264,10 @@ sub delete_primary_key
     my $col = shift;
 
     my $name = $col->name;
-    Alzabo::Exception::Params->throw( error => "Column $name doesn't exist in $self->{name}" )
+    params_exception "Column $name doesn't exist in $self->{name}"
 	unless $self->{columns}->EXISTS($name);
 
-    Alzabo::Exception::Params->throw( error => "Column $name is not a primary key" )
+    params_exception "Column $name is not a primary key"
         unless $col->is_primary_key;
 
     my $idx = $self->{columns}->Indices($name);
@@ -289,6 +292,21 @@ sub add_foreign_key
     {
 	push @{ $self->{fk}{ $fk->table_to->name }{ $c->name } }, $fk;
     }
+
+    if ( ( $fk->is_one_to_one || $fk->is_one_to_many )
+         && !
+         ( $self->primary_key_size == grep { $_->is_primary_key } $fk->columns_from )
+       )
+    {
+        my $i = Alzabo::Create::Index->new( table   => $self,
+                                            columns => [ $fk->columns_from ],
+                                            unique  => 1 );
+
+        # could already have a non-unique index (grr, index id()
+        # method is somewhat broken)
+        $self->delete_index($i) if $self->has_index( $i->id );
+        $self->add_index($i);
+    }
 }
 
 sub delete_foreign_key
@@ -300,18 +318,21 @@ sub delete_foreign_key
 
     foreach my $c ( $fk->columns_from )
     {
-	Alzabo::Exception::Params->throw( error => "Column " . $c->name . " doesn't exist in $self->{name}" )
+	params_exception "Column " . $c->name . " doesn't exist in $self->{name}"
 	    unless $self->{columns}->EXISTS( $c->name );
     }
 
-    Alzabo::Exception::Params->throw( error => "No foreign keys to " . $fk->table_to->name . " exist in $self->{name}" )
-	unless exists $self->{fk}{ $fk->table_to->name };
+    params_exception
+        "No foreign keys to " . $fk->table_to->name . " exist in $self->{name}"
+            unless exists $self->{fk}{ $fk->table_to->name };
 
     my @new_fk;
     foreach my $c ( $fk->columns_from )
     {
-	Alzabo::Exception::Params->throw( error => "Column " . $c->name . " is not a foreign key to " . $fk->table_to->name . " in $self->{name}" )
-	    unless exists $self->{fk}{ $fk->table_to->name }{ $c->name };
+	params_exception
+            "Column " . $c->name . " is not a foreign key to " .
+            $fk->table_to->name . " in $self->{name}"
+                unless exists $self->{fk}{ $fk->table_to->name }{ $c->name };
 
 	foreach my $current_fk ( @{ $self->{fk}{ $fk->table_to->name }{ $c->name } } )
 	{
@@ -351,7 +372,7 @@ sub add_index
     my $i = shift;
 
     my $id = $i->id;
-    Alzabo::Exception::Params->throw( error => "Index already exists (id $id)." )
+    params_exception "Index already exists (id $id)."
 	if $self->{indexes}->EXISTS($id);
 
     $self->{indexes}->STORE( $id, $i );
@@ -366,7 +387,7 @@ sub delete_index
     validate_pos( @_, { isa => 'Alzabo::Create::Index' } );
     my $i = shift;
 
-    Alzabo::Exception::Params->throw( error => "Index does not exist." )
+    params_exception "Index does not exist."
 	unless $self->{indexes}->EXISTS( $i->id );
 
     $self->{indexes}->DELETE( $i->id );
@@ -411,6 +432,49 @@ sub register_column_name_change
     }
 }
 
+sub set_attributes
+{
+    my $self = shift;
+
+    validate_pos( @_, ( { type => SCALAR } ) x @_ );
+
+    %{ $self->{attributes} } = ();
+
+    foreach (@_)
+    {
+	$self->add_attribute($_);
+    }
+}
+
+sub add_attribute
+{
+    my $self = shift;
+
+    validate_pos( @_, { type => SCALAR } );
+    my $attr = shift;
+
+    $attr =~ s/^\s+//;
+    $attr =~ s/\s+$//;
+
+    $self->schema->rules->validate_table_attribute( table     => $self,
+                                                    attribute => $attr );
+
+    $self->{attributes}{$attr} = 1;
+}
+
+sub delete_attribute
+{
+    my $self = shift;
+
+    validate_pos( @_, { type => SCALAR } );
+    my $attr = shift;
+
+    params_exception "Table " . $self->name . " doesn't have attribute $attr"
+	unless exists $self->{attributes}{$attr};
+
+    delete $self->{attributes}{$attr};
+}
+
 sub set_comment { $_[0]->{comment} = defined $_[1] ? $_[1] : '' }
 
 sub save_current_name
@@ -452,7 +516,7 @@ C<Alzabo::Table>
 
 =head2 new
 
-=head3 Parameters
+The constructor takes the following parameters:
 
 =over 4
 
@@ -462,19 +526,17 @@ The schema to which this table belongs.
 
 =item * name => $name
 
+=item * attributes => \@attributes
+
 =item * comment => $comment
 
 An optional comment.
 
 =back
 
-=head3 Returns
+It returns a new C<Alzabo::Create::Table> object.
 
-A new C<Alzabo::Create::Table> object.
-
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =for pod_merge schema
 
@@ -484,6 +546,9 @@ L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 Changes the name of the table.
 
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
+
 =for pod_merge column
 
 =for pod_merge columns
@@ -496,43 +561,30 @@ Creates a new L<C<Alzabo::Create::Column>|Alzabo::Create::Column>
 object and adds it to the table.  This object is the function's return
 value.
 
-In addition, if the before or after parameter is given, the
-L<C<move_column>|move_column> method is called to move the new column.
+In addition, if a "before" or "after" parameter is given, the
+L<C<move_column()>|move_column> method is called to move the new
+column.
 
-This method takes all of the same parameters as the
-L<C<Alzabo::Create::Column>|Alzabo::Create::Column> method except the
-C<table> parameter, which is automatically added.
+This method takes all of the same parameters as the L<C<<
+Alzabo::Create::Column->new() >>|Alzabo::Create::Column> method except
+the "table" parameter, which is automatically supplied.
 
-=head3 Additional Parameters
+This method also accepts an additional parameter, "primary_key",
+indicating whether or not the column is part of the table's primary
+key.
 
-=over 4
+Returns a new L<C<Alzabo::Create::Column>|Alzabo::Create::Column> object.
 
-=item * primary_key => 0 or 1
-
-If this value is true, then the
-L<C<add_primary_key>|Alzabo::Create::Table/add_primary_key
-(Alzabo::Create::Column object)> method will be called after this new
-column is made in order to make a it a primary key for the table.
-
-=item * after => C<Alzabo::Create::Column> object
-
-... or ...
-
-=item * before => C<Alzabo::Create::Column> object
-
-=back
-
-=head3 Returns
-
-A new L<C<Alzabo::Create::Column>|Alzabo::Create::Column> object.
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
 
 =head2 add_column
 
-Adds a column to the table.  If a before or after parameter is given
-then the L<C<move_column>|move_column> method will be called to move
-the new column to the appropriate position.
+Adds a column to the table.  If a "before" or "after" parameter is
+given then the L<C<move_column()>|move_column> method will be called
+to move the new column to the appropriate position.
 
-=head3 Parameters
+It takes the following parameters:
 
 =over 4
 
@@ -546,21 +598,18 @@ the new column to the appropriate position.
 
 =back
 
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
 
 =head2 delete_column (C<Alzabo::Create::Column> object)
 
 Deletes a column from the table.
 
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =head2 move_column
 
-=head3 Parameters
+This method takes the following parameters:
 
 =over 4
 
@@ -582,9 +631,7 @@ Move the column after this column.
 
 =back
 
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =for pod_merge primary_key
 
@@ -596,17 +643,13 @@ Make the given column part of the table's primary key.  The primary
 key is an ordered list of columns.  The given column will be added to
 the end of this list.
 
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =head2 delete_primary_key (C<Alzabo::Create::Column> object)
 
 Delete the given column from the primary key.
 
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =for pod_merge foreign_keys
 
@@ -623,54 +666,85 @@ L<C<Alzabo::Create::ForeignKey-E<gt>new>|Alzabo::Create::ForeignKey/new>
 method except for the table parameter, which is automatically added.
 The foreign key object that is created is then added to the table.
 
-=head3 returns
+If the foreign key being made is 1..1 or 1..n, then a unique index
+will be created on the columns involved in the "1" side of the foreign
+key, unless they are the table's primary key.
 
-A new L<C<Alzabo::Create::ForeignKey>|Alzabo::Create::ForeignKey>
-object.
+Returns a new
+L<C<Alzabo::Create::ForeignKey>|Alzabo::Create::ForeignKey> object.
+
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =head2 add_foreign_key (C<Alzabo::Create::ForeignKey> object)
 
 Adds the given foreign key to the table.
 
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+
 =head2 delete_foreign_key (C<Alzabo::Create::ForeignKey> object)
 
 Deletes the given foreign key from the table
 
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =for pod_merge index
 
+=for pod_merge has_index
+
 =for pod_merge indexes
 
 =head2 make_index
 
-Takes the same parameters as the
-L<C<Alzabo::Create::Index-E<gt>new>|Alzabo::Create::Index/new> method
-except for the C<table> parameter, which is automatically added.  The
-index object that is created is then added to the table.
+Takes the same parameters as the L<C<< Alzabo::Create::Index->new()
+>>|Alzabo::Create::Index/new> method except for the "table" parameter,
+which is automatically added.  The index object that is created is
+then added to the table.
 
-=head3 Returns
+Returns the new L<C<Alzabo::Create::Index>|Alzabo::Create::Index>
+object.
 
-A new L<C<Alzabo::Create::Index>|Alzabo::Create::Index> object.
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =head2 add_index (C<Alzabo::Create::Index> object)
 
 Adds the given index to the table.
 
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =head2 delete_index (C<Alzabo::Create::Index> object)
 
-Deletes an index from the table.
+Deletes the specified index from the table.
 
-=head3 Throws
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+
+=for pod_merge attributes
+
+=for pod_merge has_attribute
+
+=head2 set_attributes (@attributes)
+
+Sets the tables's attributes.  These are strings describing the table
+(for example, valid attributes in MySQL are "TYPE = INNODB" or
+"AUTO_INCREMENT = 100").
+
+You can also set table constraints as attributes.  Alzabo will
+generate correct SQL for both actual attributes and constraints.
+
+=head2 add_attribute ($attribute)
+
+Add an attribute to the column's list of attributes.
+
+=head2 delete_attribute ($attribute)
+
+Delete the given attribute from the column's list of attributes.
 
 L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
+=head2 former_name
+
+If the table's name has been changed since the last time the schema
+was instantiated, this method returns the table's previous name.
+
 =for pod_merge comment
 
 =head2 set_comment ($comment)
