@@ -36,12 +36,12 @@ sub connect
                                      name => $self->{schema}->name
                                    );
 
-    my @vars = $self->rows(sql=>'SHOW VARIABLES');
-    foreach (@vars)
+    foreach ( $self->rows( sql => 'SHOW VARIABLES' ) )
     {
 	if ( $_->[0] eq 'sql_mode' )
 	{
-	    $self->{mysql_ansi_mode} = $_->[1] & 4;
+	    # some versions of mysql may return '' for sql_mode
+	    $self->{mysql_ansi_mode} = ( $_->[1] ? $_->[1] : 0 ) & 4;
 	    last;
 	}
     }
@@ -68,13 +68,7 @@ sub supports_referential_integrity
 {
     my $self = shift;
 
-    $self->_check_dbh;
-
-    my $version = $self->{dbh}{mysql_serverinfo};
-
-    $version =~ s/\D//;
-
-    my ($maj, $min, $p) = split /\./, $version;
+    my ($maj, $min, $p) = $self->_version_components;
 
     if ( $maj == 3 )
     {
@@ -275,15 +269,15 @@ methods in Alzabo::Driver.
 =head2 connect, create_database, drop_database
 
 Besides the parameters listed in L<the Alzabo::Driver
-docs|Alzabo::Driver/Parameters for the connect, create_database, and
-drop_database>, these methods will also include any parameter starting
-with C<mysql_> in the DSN used to connect to the database.  This
-allows you to pass parameters such as C<mysql_default_file>.  See the
-L<DBD::mysql docs|DBD::mysql> for more details.
+docs|Alzabo::Driver/Parameters for connect(),
+create_database(), and drop_database()>, these methods will also
+include any parameter starting with C<mysql_> in the DSN used to
+connect to the database.  This allows you to pass parameters such as
+"mysql_default_file".  See the DBD::mysql docs for more details.
 
 =head2 schemas
 
-This method accepts optional C<host> and C<port> parameters.
+This method accepts optional "host" and "port" parameters.
 
 =head2 get_last_id
 
